==> nextcloud-29.0.12.tgz: nextcloud/apps/circles/l10n/cy_GB.js <==
OC.L10N.register(
    "circles",
    {
    "You deleted {circle}" : "Rydych wedi dileu {circle}",
    "{author} deleted {circle}" : "Mae {author} wedi dileu {circle}",
    "You removed {member} from {circle}" : "Rydych wedi dileu {member} o {circle}",
    "You joined {circle}" : "Rydych wedi ymuno â {circle}",
    "{member} joined {circle}" : "Ymunodd {member} â {circle}",
    "You accepted the invitation to join {circle}" : "Rydych wedi derbyn y gwahoddiad i ymuno â {circle}",
    "{member} accepted the invitation to join {circle}" : "Derbyniodd {member} y gwahoddiad i ymuno â {circle}",
    "You added {member} as member to {circle}" : "Rydych wedi ychwanegu {member} fel aelod at {circle}",
    "You have been added as member to {circle} by {author}" : "Rydych wedi eich ychwanegu fel aelod i {circle} gan {author}",
    "{member} has been added as member to {circle} by {author}" : "Mae {member} wedi'i ychwanegu fel aelod i {circle} gan {author}",
    "You added {external} to {circle}" : "Rydych wedi ychwanegu {external} at {circle}",
    "{external} has been added to {circle} by {author}" : "Mae {external} wedi'i ychwanegu at {circle} gan {author}",
    "You accepted {member}'s request to join {circle}" : "Rydych wedi derbyn cais {member} i ymuno â {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Mae eich cais i ymuno â {circle} wedi'i dderbyn gan {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "Mae cais {member} i ymuno â {circle} wedi'i dderbyn gan {author}",
    "You left {circle}" : "Rydych wedi gadael {circle}",
    "{member} left {circle}" : "Gadawodd {member} {circle}",
    "You declined the invitation to join {circle}" : "Rydych wedi gwrthod y gwahoddiad i ymuno â {circle}",
    "{member} declined an invitation to join {circle}" : "Mae {member} wedi gwrthod gwahoddiad i ymuno â {circle}",
    "You cancelled your request to join {circle}" : "Rydych chi wedi diddymu'ch cais i ymuno â {circle}",
    "You have been removed from {circle} by {author}" : "Rydych wedi cael eich tynnu o {circle} gan {author}",
    "{member} has been removed from {circle} by {author}" : "Mae {member} wedi'i dynnu o {circle} gan {author}",
    "You removed {external} from {circle}" : "Rydych wedi dileu {external} o {circle}",
    "{external} has been removed from {circle} by {author}" : "Mae {external} wedi'i dynnu o {circle} gan {author}",
    "You cancelled {member}'s invitation to join {circle}" : "Rydych wedi diddymu gwahoddiad {member} i ymuno â {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "Mae eich gwahoddiad i ymuno â {circle} wedi'i ddiddymu gan {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "Mae {author} wedi diddymu gwahoddiad {member} i ymuno â {circle}",
    "You dismissed {member}'s request to join {circle}" : "Rydych wedi diystyru cais {member} i ymuno â {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Mae eich cais i ymuno â {circle} wedi'i wrthod gan {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "Mae cais {member} i ymuno â {circle} wedi'i wrthod gan {author}",
    "You invited {member} to join {circle}" : "Rydych wedi gwahodd {member} i ymuno â {circle}",
    "You have been invited to join {circle} by {author}" : "Rydych wedi cael eich gwahodd i ymuno â {circle} gan {author}",
    "{member} has been invited to join {circle} by {author}" : "Mae {member} wedi cael gwahoddiad i ymuno â {circle} gan {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Rydych wedi newid lefel {member} yn {circle} i %1$s",
    "{author} changed your level in {circle} to %1$s" : "Newidiodd {author} eich lefel yn {circle} i %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "Newidiodd {author} lefel {member} yn {circle} i %1$s",
    "You sent a request to join {circle}" : "Rydych wedi anfon cais i ymuno â {circle}",
    "{member} sent a request to join {circle}" : "Mae {member} wedi anfon cais i ymuno â {circle}",
    "You are the new owner of {circle}" : "Chi yw perchennog newydd {circle}",
    "{member} is the new owner of {circle}" : "{member} yw perchennog newydd {circle}",
    "Shared to Circles" : "Wedi'i rannu i Gylchoedd",
    "Single" : "Unigol",
    "Personal" : "Personol",
    "System" : "System",
    "Visible" : "Gweladwy",
    "Open" : "Ar Agor",
    "Invite" : "Gwahoddiad",
    "Friends" : "Ffrindiau",
    "Password protected" : "Diogelwyd â chyfrinair",
    "No Owner" : "Dim Perchennog",
    "Hidden" : "Cudd",
    "Backend" : "Rhan cefn",
    "Local" : "Lleol",
    "Root" : "Gwraidd",
    "Federated" : "Ffederaleiddiwyd",
    "Mount point" : "Pwynt arosod",
    "Nextcloud Account" : "Cyfrif Nextcloud",
    "Nextcloud Group" : "Grŵp Nextcloud",
    "Email address" : "Cyfeiriad e-bost",
    "Contact" : "Cysylltu",
    "Circle" : "Cylch",
    "Nextcloud App" : "Ap Nextcloud",
    "Member" : "Aelod",
    "Moderator" : "Cymedrolwr",
    "Admin" : "Gweinyddwr",
    "Owner" : "Perchennog",
    "%s shared »%s« with you." : "Mae %s wedi rhannu »%s« â chi.",
    "%s shared »%s« with \"%s\"." : "Mae %s wedi rhannu »%s« gyda \"%s\".",
    "%s on %s" : "%s ar %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "Mae %1$s wedi rhannu »%2$s« â chi.\nDylech fod wedi derbyn e-bost ar wahân yn barod gyda dolen i gael mynediad iddo.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "Mae %1$s wedi rhannu »%2$s« â chi. Dylech fod wedi derbyn e-bost ar wahân yn barod gyda dolen i gael mynediad iddo.",
    "Password to access »%1$s« shared to you by %2$s" : "Cyfrinair i gael mynediad iddo »%1$s« wedi'i rannu â chi gan %2$s",
    "Password to access »%s«" : "Cyfrinair i gael mynediad iddo »%s«",
    "It is protected with the following password:" : "Mae wedi'i warchod gyda'r cyfrinair canlynol:",
    "%1$s via %2$s" : "%1$s trwy %2$s",
    "Click the button below to open it." : "Cliciwch ar y botwm isod i'w agor.",
    "Open »%s«" : "Agor »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "Mae %1$s wedi rhannu sawl ffeil gyda chi.\nDylech fod wedi derbyn e-bost ar wahân yn barod gyda dolen i gael mynediad iddynt.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "Mae %1$s wedi rhannu sawl ffeil gyda chi. Dylech fod wedi derbyn e-bost ar wahân yn barod gyda dolen i gael mynediad iddynt.",
    "Password to access files shared to you by %1$s" : "Cyfrinair i gael mynediad at ffeiliau a rennir â chi gan %1$s",
    "Password to access files" : "Cyfrinair i gael mynediad i ffeiliau",
    "%s shared multiple files with \"%s\"." : "Mae %s wedi rhannu sawl ffeil gyda \"%s\".",
    "%s shared multiple files with you." : "Mae %s wedi rhannu sawl ffeil gyda chi.",
    "Boot up" : "Cychwyn",
    "Nextcloud Initialization" : "Cychwyniad Nextcloud",
    "Circles App Initialization" : "Cychwyn Ap Cylchoedd",
    "Fresh installation status" : "Statws gosodiad newydd",
    "Building Local Database" : "Adeiladu Cronfa Ddata Lleol",
    "Testing Basic Circle Creation" : "Profi Creu Cylch Sylfaenol",
    "Adding local users and moderators" : "Ychwanegu defnyddwyr a chymedrolwyr lleol",
    "This feature is not available for personal circles" : "Nid yw'r nodwedd hon ar gael ar gyfer cylchoedd personol",
    "This member is not a moderator" : "Nid yw'r aelod hwn yn gymedrolwr",
    "Insufficient privileges" : "Breintiau annigonol",
    "This member does not exist" : "Nid yw'r aelod hwn yn bodoli",
    "Level cannot be changed for this type of member" : "Ni ellir newid lefel ar gyfer y math hwn o aelod",
    "You are already a member of this circle" : "Rydych chi eisoes yn aelod o'r cylch hwn",
    "You have been blocked from this circle" : "Rydych chi wedi cael eich rhwystro o'r cylch hwn",
    "The account is already a member of this circle" : "Mae'r cyfrif eisoes yn aelod o'r cylch hwn",
    "The account has already been invited into this circle" : "Mae'r cyfrif eisoes wedi'i wahodd i'r cylch hwn",
    "Accept" : "Derbyn",
    "Refuse" : "Gwrthod",
    "%s" : "%s",
    "%s owned by %s" : "%s sy'n eiddo i %s",
    "%s shared a file with \"%s\"." : "Mae %s wedi rhannu ffeil gyda \"%s\".",
    "%s shared a file with you." : "Mae %s wedi rhannu ffeil gyda chi.",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "Mae %1$s wedi rhannu rhywfaint o gynnwys â chi.\nDylech fod wedi derbyn e-bost ar wahân yn barod gyda dolen i gael mynediad iddo.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "Mae %1$s wedi rhannu rhywfaint o gynnwys â chi. Dylech fod wedi derbyn e-bost ar wahân yn barod gyda dolen i gael mynediad iddo.",
    "Password to access content shared with you by %1$s" : "Cyfrinair i gael mynediad at gynnwys a rennir gyda chi gan %1$s",
    "Password to access content" : "Cyfrinair i gyrchu cynnwys",
    "Bring cloud-users closer together." : "Dod â defnyddwyr cwmwl yn nes at ei gilydd.",
    "No files in here" : "Dim ffeiliau i mewn yma",
    "No entries found in this folder" : "Ni chanfuwyd unrhyw gofnodion yn y ffolder hwn",
    "Name" : "Enw",
    "Size" : "Maint",
    "Modified" : "Addaswyd",
    "You are now a member of the Circle \"%2$s\"" : "Rydych nawr yn aelod o'r Cylch \"%2$s\"",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "Rydych chi wedi cael eich gwahodd gan %1$s i'r Cylch \"%2$s\"",
    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "Anfonodd %1$s gais i fod yn aelod o'r Cylch \"%2$s\"",
    "Leave the circle" : "Gadael y cylch"
},
"nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");

==> nextcloud-30.0.5.tgz: nextcloud/apps/circles/l10n/cy_GB.js <==
OC.L10N.register(
    "circles",
    {
    "You deleted {circle}" : "Rydych wedi dileu {circle}",
    "{author} deleted {circle}" : "Mae {author} wedi dileu {circle}",
    "You removed {member} from {circle}" : "Rydych wedi dileu {member} o {circle}",
    "You joined {circle}" : "Rydych wedi ymuno â {circle}",
    "{member} joined {circle}" : "Ymunodd {member} â {circle}",
    "You accepted the invitation to join {circle}" : "Rydych wedi derbyn y gwahoddiad i ymuno â {circle}",
    "{member} accepted the invitation to join {circle}" : "Derbyniodd {member} y gwahoddiad i ymuno â {circle}",
    "You added {member} as member to {circle}" : "Rydych wedi ychwanegu {member} fel aelod at {circle}",
    "You have been added as member to {circle} by {author}" : "Rydych wedi eich ychwanegu fel aelod i {circle} gan {author}",
    "{member} has been added as member to {circle} by {author}" : "Mae {member} wedi'i ychwanegu fel aelod i {circle} gan {author}",
    "You added {external} to {circle}" : "Rydych wedi ychwanegu {external} at {circle}",
    "{external} has been added to {circle} by {author}" : "Mae {external} wedi'i ychwanegu at {circle} gan {author}",
    "You accepted {member}'s request to join {circle}" : "Rydych wedi derbyn cais {member} i ymuno â {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Mae eich cais i ymuno â {circle} wedi'i dderbyn gan {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "Mae cais {member} i ymuno â {circle} wedi'i dderbyn gan {author}",
    "You left {circle}" : "Rydych wedi gadael {circle}",
    "{member} left {circle}" : "Gadawodd {member} {circle}",
    "You declined the invitation to join {circle}" : "Rydych wedi gwrthod y gwahoddiad i ymuno â {circle}",
    "{member} declined an invitation to join {circle}" : "Mae {member} wedi gwrthod gwahoddiad i ymuno â {circle}",
    "You cancelled your request to join {circle}" : "Rydych chi wedi diddymu'ch cais i ymuno â {circle}",
    "You have been removed from {circle} by {author}" : "Rydych wedi cael eich tynnu o {circle} gan {author}",
    "{member} has been removed from {circle} by {author}" : "Mae {member} wedi'i dynnu o {circle} gan {author}",
    "You removed {external} from {circle}" : "Rydych wedi dileu {external} o {circle}",
    "{external} has been removed from {circle} by {author}" : "Mae {external} wedi'i dynnu o {circle} gan {author}",
    "You cancelled {member}'s invitation to join {circle}" : "Rydych wedi diddymu gwahoddiad {member} i ymuno â {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "Mae eich gwahoddiad i ymuno â {circle} wedi'i ddiddymu gan {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "Mae {author} wedi diddymu gwahoddiad {member} i ymuno â {circle}",
    "You dismissed {member}'s request to join {circle}" : "Rydych wedi diystyru cais {member} i ymuno â {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Mae eich cais i ymuno â {circle} wedi'i wrthod gan {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "Mae cais {member} i ymuno â {circle} wedi'i wrthod gan {author}",
    "You invited {member} to join {circle}" : "Rydych wedi gwahodd {member} i ymuno â {circle}",
    "You have been invited to join {circle} by {author}" : "Rydych wedi cael eich gwahodd i ymuno â {circle} gan {author}",
    "{member} has been invited to join {circle} by {author}" : "Mae {member} wedi cael gwahoddiad i ymuno â {circle} gan {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Rydych wedi newid lefel {member} yn {circle} i %1$s",
    "{author} changed your level in {circle} to %1$s" : "Newidiodd {author} eich lefel yn {circle} i %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "Newidiodd {author} lefel {member} yn {circle} i %1$s",
    "You sent a request to join {circle}" : "Rydych wedi anfon cais i ymuno â {circle}",
    "{member} sent a request to join {circle}" : "Mae {member} wedi anfon cais i ymuno â {circle}",
    "You are the new owner of {circle}" : "Chi yw perchennog newydd {circle}",
    "{member} is the new owner of {circle}" : "{member} yw perchennog newydd {circle}",
    "Shared to Circles" : "Wedi'i rannu i Gylchoedd",
    "Single" : "Unigol",
    "Personal" : "Personol",
    "System" : "System",
    "Visible" : "Gweladwy",
    "Open" : "Ar Agor",
    "Invite" : "Gwahoddiad",
    "Friends" : "Ffrindiau",
    "Password protected" : "Diogelwyd â chyfrinair",
    "No Owner" : "Dim Perchennog",
    "Hidden" : "Cudd",
    "Backend" : "Rhan cefn",
    "Local" : "Lleol",
    "Root" : "Gwraidd",
    "Federated" : "Ffederaleiddiwyd",
    "Mount point" : "Pwynt arosod",
    "Nextcloud Account" : "Cyfrif Nextcloud",
    "Nextcloud Group" : "Grŵp Nextcloud",
    "Email address" : "Cyfeiriad e-bost",
    "Contact" : "Cysylltu",
    "Circle" : "Cylch",
    "Nextcloud App" : "Ap Nextcloud",
    "Member" : "Aelod",
    "Moderator" : "Cymedrolwr",
    "Admin" : "Gweinyddwr",
    "Owner" : "Perchennog",
    "%s shared »%s« with you." : "Mae %s wedi rhannu »%s« â chi.",
    "%s shared »%s« with \"%s\"." : "Mae %s wedi rhannu »%s« gyda \"%s\".",
    "%s on %s" : "%s ar %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "Mae %1$s wedi rhannu »%2$s« â chi.\nDylech fod wedi derbyn e-bost ar wahân yn barod gyda dolen i gael mynediad iddo.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "Mae %1$s wedi rhannu »%2$s« â chi. Dylech fod wedi derbyn e-bost ar wahân yn barod gyda dolen i gael mynediad iddo.",
    "Password to access »%1$s« shared to you by %2$s" : "Cyfrinair i gael mynediad iddo »%1$s« wedi'i rannu â chi gan %2$s",
    "Password to access »%s«" : "Cyfrinair i gael mynediad iddo »%s«",
    "It is protected with the following password:" : "Mae wedi'i warchod gyda'r cyfrinair canlynol:",
    "%1$s via %2$s" : "%1$s trwy %2$s",
    "Click the button below to open it." : "Cliciwch ar y botwm isod i'w agor.",
    "Open »%s«" : "Agor »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "Mae %1$s wedi rhannu sawl ffeil gyda chi.\nDylech fod wedi derbyn e-bost ar wahân yn barod gyda dolen i gael mynediad iddynt.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "Mae %1$s wedi rhannu sawl ffeil gyda chi. Dylech fod wedi derbyn e-bost ar wahân yn barod gyda dolen i gael mynediad iddynt.",
    "Password to access files shared to you by %1$s" : "Cyfrinair i gael mynediad at ffeiliau a rennir â chi gan %1$s",
    "Password to access files" : "Cyfrinair i gael mynediad i ffeiliau",
    "%s shared multiple files with \"%s\"." : "Mae %s wedi rhannu sawl ffeil gyda \"%s\".",
    "%s shared multiple files with you." : "Mae %s wedi rhannu sawl ffeil gyda chi.",
    "Boot up" : "Cychwyn",
    "Nextcloud Initialization" : "Cychwyniad Nextcloud",
    "Circles App Initialization" : "Cychwyn Ap Cylchoedd",
    "Fresh installation status" : "Statws gosodiad newydd",
    "Building Local Database" : "Adeiladu Cronfa Ddata Lleol",
    "Testing Basic Circle Creation" : "Profi Creu Cylch Sylfaenol",
    "Adding local users and moderators" : "Ychwanegu defnyddwyr a chymedrolwyr lleol",
    "This feature is not available for personal circles" : "Nid yw'r nodwedd hon ar gael ar gyfer cylchoedd personol",
    "This member is not a moderator" : "Nid yw'r aelod hwn yn gymedrolwr",
    "Insufficient privileges" : "Breintiau annigonol",
    "This member does not exist" : "Nid yw'r aelod hwn yn bodoli",
    "Level cannot be changed for this type of member" : "Ni ellir newid lefel ar gyfer y math hwn o aelod",
    "You are already a member of this circle" : "Rydych chi eisoes yn aelod o'r cylch hwn",
    "You have been blocked from this circle" : "Rydych chi wedi cael eich rhwystro o'r cylch hwn",
    "The account is already a member of this circle" : "Mae'r cyfrif eisoes yn aelod o'r cylch hwn",
    "The account has already been invited into this circle" : "Mae'r cyfrif eisoes wedi'i wahodd i'r cylch hwn",
    "Accept" : "Derbyn",
    "Refuse" : "Gwrthod",
    "%s" : "%s",
    "%s owned by %s" : "%s sy'n eiddo i %s",
    "%s shared a file with \"%s\"." : "Mae %s wedi rhannu ffeil gyda \"%s\".",
    "%s shared a file with you." : "Mae %s wedi rhannu ffeil gyda chi.",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "Mae %1$s wedi rhannu rhywfaint o gynnwys â chi.\nDylech fod wedi derbyn e-bost ar wahân yn barod gyda dolen i gael mynediad iddo.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "Mae %1$s wedi rhannu rhywfaint o gynnwys â chi. Dylech fod wedi derbyn e-bost ar wahân yn barod gyda dolen i gael mynediad iddo.",
    "Password to access content shared with you by %1$s" : "Cyfrinair i gael mynediad at gynnwys a rennir gyda chi gan %1$s",
    "Password to access content" : "Cyfrinair i gyrchu cynnwys",
    "Bring cloud-users closer together." : "Dod â defnyddwyr cwmwl yn nes at ei gilydd.",
    "No files in here" : "Dim ffeiliau i mewn yma",
    "No entries found in this folder" : "Ni chanfuwyd unrhyw gofnodion yn y ffolder hwn",
    "Name" : "Enw",
    "Size" : "Maint",
    "Modified" : "Addaswyd",
    "Circles" : "Cylchoedd",
    "Circles' files" : "Ffeiliau cylchoedd",
    "Select circles to filter by" : "Dewiswch gylchoedd i hidlo yn eu herbyn",
    "No circles found" : "Heb ganfod cylchoedd",
    "Please select circles to filter by" : "Dewiswch gylchoedd i hidlo yn eu herbyn",
    "No files found for the selected circles" : "Ni chanfuwyd unrhyw ffeiliau ar gyfer y cylchoedd a ddewiswyd",
    "You created the circle {circle}" : "Rydych chi wedi creu'r cylch {circle}",
    "{author} created the circle {circle}" : "Creodd {author} y cylch {circle}",
    "On events happening in a <strong>Circle</strong> of which you are a member" : "Ar ddigwyddiadau sy'n digwydd mewn <strong>Cylch</strong> yr ydych yn aelod ohono",
    "Any important event in a <strong>Circle</strong> you are moderating" : "Unrhyw ddigwyddiad pwysig mewn <strong>Cylch</strong> rydych chi'n ei gymedroli",
    "On global events happening in any <strong>Circle</strong>" : "Ar ddigwyddiadau eang sy'n digwydd mewn unrhyw <strong>Gylch</strong>",
    "Join Request" : "Cais i Ymuno",
    "Password Protected" : "Diogelu gyda Chyfrinair",
    "Circle Invite" : "Gwahoddiad Cylch",
    "Email Address" : "Cyfeiriad E-bost",
    "Circle not found" : "Cylch heb ei ddarganfod",
    "Circle not found " : "Cylch heb ei ddarganfod ",
    "This account is already a member of the circle" : "Mae'r cyfrif hwn eisoes yn aelod o'r cylch",
    "Federated link not found" : "Heb ganfod dolen ffederal",
    "The circle is not federated" : "Nid yw'r cylch wedi'i ffederaleiddio",
    "You cannot join this circle" : "Ni allwch ymuno â'r cylch hwn",
    "This member is the owner of the circle" : "Yr aelod hwn yw perchennog y cylch",
    "%s (Circle owned by %s)" : "%s (Mae'r cylch yn eiddo i %s)",
    "You are now a member of the Circle \"%2$s\"" : "Rydych nawr yn aelod o'r Cylch \"%2$s\"",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "Rydych chi wedi cael eich gwahodd gan %1$s i'r Cylch \"%2$s\"",
    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "Anfonodd %1$s gais i fod yn aelod o'r Cylch \"%2$s\"",
    "Leave the circle" : "Gadael y cylch",
    "Personal Circle" : "Cylch Personol",
    "You need a specify a type of circle" : "Mae angen i chi nodi math o gylch",
    "A circle with that name exists" : "Mae cylch gyda'r enw hwnnw yn bodoli",
    "This member is not the owner of the circle" : "Nid yr aelod hwn yw perchennog y cylch",
    "This member is not an admin of the circle" : "Nid yw'r aelod hwn yn weinyddwr y cylch",
    "Group contains too many members" : "Mae'r grŵp yn cynnwys gormod o aelodau",
    "This group does not exist" : "Nid yw'r grŵp hwn yn bodoli",
    "This group is already linked to the circle" : "Mae'r grŵp hwn eisoes yn gysylltiedig â'r cylch",
    "You cannot edit level in a personal circle" : "Ni allwch olygu lefel mewn cylch personol",
    "Group cannot be set as owner of a circle" : "Ni ellir gosod grŵp fel perchennog cylch",
    "now" : "nawr",
    "This account does not exist" : "Nid yw'r cyfrif hwn yn bodoli",
    "Email format is not valid" : "Nid yw fformat e-bost yn ddilys",
    "This contact is not available" : "Dyw'r cyswllt ddim ar gael bellach",
    "You have no permission to create a new circle" : "Nid oes gennych ganiatâd i greu cylch newydd",
    "This item is already shared with this circle" : "Mae'r eitem hon eisoes wedi'i rhannu â'r cylch hwn",
    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "Mae cylchoedd yn galluogi pobl i greu eu grwpiau eu hunain o bobl/cydweithwyr/ffrindiau.\nYna gall unrhyw ap arall ddefnyddio'r grwpiau hynny o bobl (neu \"gylchoedd\") at ddibenion rhannu."
},
"nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");
